-----------------------------------------------------------------------------------------------
-- Client Lua Script for AFKAlert
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- AFKAlert Module Definition
-----------------------------------------------------------------------------------------------
local AFKAlert = {} 

-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999

local nAlertSound = 166    -- Challenge Begins sound, by default
local bEnabled = true
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function AFKAlert:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function AFKAlert:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- AFKAlert OnLoad
-----------------------------------------------------------------------------------------------
function AFKAlert:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("AFKAlert.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- AFKAlert OnDocLoaded
-----------------------------------------------------------------------------------------------
function AFKAlert:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "AFKAlertConfig", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("buzz", "OnAFKAlertOn", self)
		Apollo.RegisterEventHandler("ChatMessage", "OnChatMessage", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- AFKAlert Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/aa"
function AFKAlert:OnAFKAlertOn(strCommand, strParam)
	--self.wndMain:Invoke() -- show the window
	if strParam and strParam == "on" then
		bEnabled = true
	elseif strParam and strParam == "off" then
		bEnabled = false
	else
		self:SetupConfigWindow()
		self.wndMain:Show(true)
	end
end

function AFKAlert:SetupConfigWindow()
	local soundID = self.wndMain:FindChild("SoundID")
	local toggle = self.wndMain:FindChild("EnableToggleButton")
	if nAlertSound then soundID:SetText(nAlertSound)
	else soundID:SetText(166) end
	toggle:SetCheck(bEnabled)
end

function AFKAlert:OnChatMessage(tChannel, tMessage, nNum)
	local strAfkMessage = Apollo.GetString(552503)
	if bEnabled and tChannel:GetName() == "System" and tMessage.arMessageSegments[1].strText == strAfkMessage then
		Sound.Play(nAlertSound)
		Apollo.AlertAppWindow()
	end
end

function AFKAlert:OnSave(nLevel)
	if nLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then return end
	tSave = {
		kAlertSound = nAlertSound,
		kEnabled = bEnabled,
		}
	return tSave
end

function AFKAlert:OnRestore(nLevel, tSave)
	if nLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then return end
	if tSave then
		nAlertSound = tSave.kAlertSound
		bEnabled = tSave.kEnabled
	end
end

function AFKAlert:OnCancel()
	if self.wndMain then self.wndMain:Show(false) end
end

function AFKAlert:OnTestPlayButtonClick()
	local soundID = self.wndMain:FindChild("SoundID")
	if soundID then Print(soundID:GetText()) end
	if tonumber(soundID:GetText()) then
		Sound.Play(soundID:GetText())
	end
end

-----------------------------------------------------------------------------------------------
-- AFKAlertForm Functions
-----------------------------------------------------------------------------------------------


---------------------------------------------------------------------------------------------------
-- AFKAlertConfig Functions
---------------------------------------------------------------------------------------------------

function AFKAlert:OnEnableToggleChecked( wndHandler, wndControl, eMouseButton )
	bEnabled = true
end

function AFKAlert:OnEnableToggleUnchecked( wndHandler, wndControl, eMouseButton )
	bEnabled = false
end

function AFKAlert:OnEditBoxChanged( wndHandler, wndControl, strText )
	if tonumber(strText) then nAlertSound = tonumber(strText) end
end

-----------------------------------------------------------------------------------------------
-- AFKAlert Instance
-----------------------------------------------------------------------------------------------
local AFKAlertInst = AFKAlert:new()
AFKAlertInst:Init()
